package com.caimei365.order.controller;

import com.alibaba.fastjson.JSONObject;
import com.caimei365.order.model.ResponseJson;
import com.caimei365.order.model.dto.SecondPayDto;
import com.caimei365.order.service.PayNonOrderService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.HttpHeaders;
import org.springframework.web.bind.annotation.*;

import java.security.NoSuchAlgorithmException;
import java.security.spec.InvalidKeySpecException;

/**
 * 二手发布支付，升级超级会员支付
 *
 * @author : Charles
 * @date : 2021/9/27
 */
@Api(tags="其他(非订单)支付API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/order/pay")
public class PayNonOrderApi {

    private final PayNonOrderService payNonOrderService;

    /**
     * 二手发布微信线上支付
     * @param secondPayDto {
     *               productId      二手发布商品id
     *               returnUrl     页面回调地址
     *               code          微信小程序code
     *               state         微信公众号state参数
     * }
     */
    @ApiOperation("二手发布微信线上支付（旧：/PayOrder/appletsSecondHandPay）(/PayOrder/secondHandPay[WEIXIN])")
    @PostMapping("/second/wechat")
    public ResponseJson<JSONObject> paySecondByWeChat(SecondPayDto secondPayDto, @RequestHeader HttpHeaders headers){
        if (null == secondPayDto.getProductId()) {
            return ResponseJson.error("二手商品Id不能为空！", null);
        }
        if (StringUtils.isEmpty(secondPayDto.getCode())) {
            return ResponseJson.error("微信code不能为空！", null);
        }
        return payNonOrderService.paySecondByWeChat(secondPayDto, headers);
    }

    /**
     * 二手发布支付宝线上支付
     * @param secondPayDto {
     *               productId      二手发布商品id
     *               returnUrl     页面回调地址
     * }
     */
    @ApiOperation("二手发布支付宝线上支付（旧：/PayOrder/secondHandPay[ALIPAY]）")
    @PostMapping("/second/alipay")
    public ResponseJson<JSONObject> paySecondByAlipay(SecondPayDto secondPayDto, @RequestHeader HttpHeaders headers){
        if (null == secondPayDto.getProductId()) {
            return ResponseJson.error("二手商品Id不能为空！", null);
        }
        if (StringUtils.isEmpty(secondPayDto.getReturnUrl())) {
            return ResponseJson.error("回调地址不能为空！", null);
        }
        return payNonOrderService.paySecondByAlipay(secondPayDto, headers);
    }

    /**
     * 二手发布银联线上支付
     * @param secondPayDto {
     *               productId     二手发布商品id
     *               returnUrl     页面回调地址
     *               bankCode      银行编码(银联支付使用)
     *               userType      用户类型(银联支付使用)企业:ENTERPRISE，个人:USER
     * }
     */
    @ApiOperation("二手发布银联线上支付（旧：/PayOrder/secondHandPay[UNIONPAY]）")
    @PostMapping("/second/union")
    public ResponseJson<JSONObject> paySecondByUnionPay(SecondPayDto secondPayDto, @RequestHeader HttpHeaders headers){
        if (null == secondPayDto.getProductId()) {
            return ResponseJson.error("二手商品Id不能为空！", null);
        }
        if (StringUtils.isEmpty(secondPayDto.getReturnUrl())) {
            return ResponseJson.error("回调地址不能为空！", null);
        }
        if (StringUtils.isEmpty(secondPayDto.getBankCode())) {
            return ResponseJson.error("银行编码不能为空！", null);
        }
        if (StringUtils.isEmpty(secondPayDto.getUserType())) {
            return ResponseJson.error("银行用户类型不能为空！", null);
        }
        return payNonOrderService.paySecondByUnionPay(secondPayDto, headers);
    }

    /**
     * 二手发布支付回调
     */
    @ApiOperation("二手发布支付回调（旧：/PayOrder/secondHandPayCallBack）")
    @GetMapping("/second/callback")
    public String paymentSecondCallback(String data) throws NoSuchAlgorithmException, InvalidKeySpecException {
        if (StringUtils.isBlank(data)) {
            return "回调参数失败";
        }
        return payNonOrderService.paymentSecondCallback(data);
    }

}
