package com.caimei365.order.service;

import com.alibaba.fastjson.JSONObject;
import com.caimei365.order.model.ResponseJson;
import com.caimei365.order.model.dto.SecondPayDto;
import org.springframework.http.HttpHeaders;

import java.security.NoSuchAlgorithmException;
import java.security.spec.InvalidKeySpecException;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/9/27
 */
public interface PayNonOrderService {
    /**
     * 二手发布微信线上支付
     * @param secondPayDto {
     *               productId      二手发布商品id
     *               returnUrl     页面回调地址
     *               code          微信小程序code
     *               state         微信公众号state参数
     * }
     */
    ResponseJson<JSONObject> paySecondByWeChat(SecondPayDto secondPayDto, HttpHeaders headers);
    /**
     * 二手发布支付宝线上支付
     * @param secondPayDto {
     *               productId      二手发布商品id
     *               returnUrl     页面回调地址
     * }
     */
    ResponseJson<JSONObject> paySecondByAlipay(SecondPayDto secondPayDto, HttpHeaders headers);
    /**
     * 二手发布银联线上支付
     * @param secondPayDto {
     *               productId       二手发布商品id
     *               returnUrl     页面回调地址
     *               bankCode      银行编码(银联支付使用)
     *               userType      用户类型(银联支付使用)企业:ENTERPRISE，个人:USER
     * }
     */
    ResponseJson<JSONObject> paySecondByUnionPay(SecondPayDto secondPayDto, HttpHeaders headers);
    /**
     * 二手发布支付回调
     */
    String paymentSecondCallback(String data) throws NoSuchAlgorithmException, InvalidKeySpecException;

}
